@@ -2,6 +2,7 @@ package app
 
 import (
 	"bytes"
+	goContext "context"
 	"fmt"
 	"os"
 	"path/filepath"
@@ -23,6 +24,7 @@ import (
 )
 
 var CleanWaitGroup sync.WaitGroup
+var Cancel goContext.CancelFunc
 
 // App is the main application object.
 type App struct {
@@ -50,6 +52,8 @@ type App struct {
 
 	helms      map[helmKey]helmexec.Interface
 	helmsMutex sync.Mutex
+
+	ctx goContext.Context
 }
 
 type HelmRelease struct {
@@ -63,6 +67,9 @@ type HelmRelease struct {
 }
 
 func New(conf ConfigProvider) *App {
+	ctx := goContext.Background()
+	ctx, Cancel = goContext.WithCancel(ctx)
+
 	return Init(&App{
 		OverrideKubeContext: conf.KubeContext(),
 		OverrideHelmBinary:  conf.HelmBinary(),
@@ -78,6 +85,7 @@ func New(conf ConfigProvider) *App {
 		ValuesFiles:         conf.StateValuesFiles(),
 		Set:                 conf.StateValuesSet(),
 		fs:                  filesystem.DefaultFileSystem(),
+		ctx:                 ctx,
 	})
 }
 
@@ -98,6 +106,7 @@ func Init(app *App) *App {
 func (a *App) Init(c InitConfigProvider) error {
 	runner := &helmexec.ShellRunner{
 		Logger: a.Logger,
+		Ctx:    a.ctx,
 	}
 	helmfileInit := NewHelmfileInit(a.OverrideHelmBinary, c, a.Logger, runner)
 	return helmfileInit.Initialize()
@@ -242,6 +251,7 @@ func (a *App) Template(c TemplateConfigProvider) error {
 			Validate:               c.Validate(),
 			Concurrency:            c.Concurrency(),
 			IncludeTransitiveNeeds: c.IncludeNeeds(),
+			Set:                    c.Set(),
 		}, func() {
 			ok, errs = a.template(run, c)
 		})
@@ -788,6 +798,7 @@ func (a *App) getHelm(st *state.HelmState) helmexec.Interface {
 	if _, ok := a.helms[key]; !ok {
 		a.helms[key] = helmexec.New(bin, helmexec.HelmExecOptions{EnableLiveOutput: a.EnableLiveOutput, DisableForceUpdate: a.DisableForceUpdate}, a.Logger, kubectx, &helmexec.ShellRunner{
 			Logger: a.Logger,
+			Ctx:    a.ctx,
 		})
 	}
 
@@ -1305,6 +1316,8 @@ func (a *App) apply(r *Run, c ApplyConfigProvider) (bool, bool, []error) {
 	st := r.state
 	helm := r.helm
 
+	helm.SetExtraArgs(argparser.GetArgs(c.Args(), r.state)...)
+
 	selectedReleases, selectedAndNeededReleases, err := a.getSelectedReleases(r, c.IncludeTransitiveNeeds())
 	if err != nil {
 		return false, false, []error{err}
@@ -1415,8 +1428,6 @@ Do you really want to apply?
 			return true, false, preapplyErrors
 		}
 
-		r.helm.SetExtraArgs(argparser.GetArgs(c.Args(), r.state)...)
-
 		// We deleted releases by traversing the DAG in reverse order
 		if len(releasesToBeDeleted) > 0 {
 			_, deletionErrs := withDAG(st, helm, a.Logger, state.PlanOptions{Reverse: true, SelectedReleases: toDelete, SkipNeeds: true}, a.WrapWithoutSelector(func(subst *state.HelmState, helm helmexec.Interface) []error {
@@ -1431,7 +1442,7 @@ Do you really want to apply?
 
 				subst.Releases = rs
 
-				return subst.DeleteReleasesForSync(&affectedReleases, helm, c.Concurrency())
+				return subst.DeleteReleasesForSync(&affectedReleases, helm, c.Concurrency(), c.Cascade())
 			}))
 
 			if len(deletionErrs) > 0 {
@@ -1550,7 +1561,7 @@ Do you really want to delete?
 
 		if len(releasesToDelete) > 0 {
 			_, deletionErrs := withDAG(st, helm, a.Logger, state.PlanOptions{SelectedReleases: toDelete, Reverse: true, SkipNeeds: true}, a.WrapWithoutSelector(func(subst *state.HelmState, helm helmexec.Interface) []error {
-				return subst.DeleteReleases(&affectedReleases, helm, c.Concurrency(), purge)
+				return subst.DeleteReleases(&affectedReleases, helm, c.Concurrency(), purge, c.Cascade())
 			}))
 
 			if len(deletionErrs) > 0 {
@@ -1822,7 +1833,7 @@ Do you really want to sync?
 
 				subst.Releases = rs
 
-				return subst.DeleteReleasesForSync(&affectedReleases, helm, c.Concurrency())
+				return subst.DeleteReleasesForSync(&affectedReleases, helm, c.Concurrency(), c.Cascade())
 			}))
 
 			if len(deletionErrs) > 0 {
