@@ -46,6 +46,7 @@ type ReposConfigProvider interface {
 type ApplyConfigProvider interface {
 	Args() string
 	PostRenderer() string
+	Cascade() string
 
 	Values() []string
 	Set() []string
@@ -63,6 +64,7 @@ type ApplyConfigProvider interface {
 	SuppressDiff() bool
 
 	DetailedExitcode() bool
+	StripTrailingCR() bool
 
 	Color() bool
 	NoColor() bool
@@ -87,6 +89,7 @@ type ApplyConfigProvider interface {
 type SyncConfigProvider interface {
 	Args() string
 	PostRenderer() string
+	Cascade() string
 
 	Values() []string
 	Set() []string
@@ -130,6 +133,7 @@ type DiffConfigProvider interface {
 	DAGConfig
 
 	DetailedExitcode() bool
+	StripTrailingCR() bool
 	Color() bool
 	NoColor() bool
 	Context() int
@@ -142,6 +146,7 @@ type DiffConfigProvider interface {
 // TODO: Remove this function once Helmfile v0.x
 type DeleteConfigProvider interface {
 	Args() string
+	Cascade() string
 
 	Purge() bool
 	SkipDeps() bool
@@ -154,6 +159,7 @@ type DeleteConfigProvider interface {
 
 type DestroyConfigProvider interface {
 	Args() string
+	Cascade() string
 
 	SkipDeps() bool
 	SkipCharts() bool
