@@ -22,13 +22,17 @@ func prependLineNumbers(text string) string {
 	return buf.String()
 }
 
-func (r *desiredStateLoader) renderPrestate(firstPassEnv *environment.Environment, baseDir, filename string, content []byte) (*environment.Environment, *state.HelmState) {
-	tmplData := state.NewEnvironmentTemplateData(*firstPassEnv, r.namespace, map[string]interface{}{})
+func (r *desiredStateLoader) renderPrestate(firstPassEnv, overrode *environment.Environment, baseDir, filename string, content []byte) (*environment.Environment, *state.HelmState) {
+	initEnv, err := firstPassEnv.Merge(overrode)
+	if err != nil {
+		return firstPassEnv, nil
+	}
+	tmplData := state.NewEnvironmentTemplateData(*initEnv, r.namespace, map[string]interface{}{})
 	firstPassRenderer := tmpl.NewFirstPassRenderer(baseDir, tmplData)
 
 	// parse as much as we can, tolerate errors, this is a preparse
 	yamlBuf, err := firstPassRenderer.RenderTemplateContentToBuffer(content)
-	if err != nil && r.logger != nil {
+	if err != nil {
 		r.logger.Debugf("first-pass rendering input of \"%s\":\n%s", filename, prependLineNumbers(string(content)))
 		r.logger.Debugf("template syntax error: %v", err)
 		if yamlBuf == nil { // we have a template syntax error, let the second parse report
@@ -36,9 +40,7 @@ func (r *desiredStateLoader) renderPrestate(firstPassEnv *environment.Environmen
 		}
 	}
 	yamlData := yamlBuf.String()
-	if r.logger != nil {
-		r.logger.Debugf("first-pass rendering output of \"%s\":\n%s", filename, prependLineNumbers(yamlData))
-	}
+	r.logger.Debugf("first-pass rendering output of \"%s\":\n%s", filename, prependLineNumbers(yamlData))
 
 	// Work-around for https://github.com/golang/go/issues/24963
 	sanitized := strings.ReplaceAll(yamlData, "<no value>", "")
@@ -51,8 +53,8 @@ func (r *desiredStateLoader) renderPrestate(firstPassEnv *environment.Environmen
 	c := r.underlying()
 	c.Strict = false
 	// create preliminary state, as we may have an environment. Tolerate errors.
-	prestate, err := c.ParseAndLoad([]byte(sanitized), baseDir, filename, r.env, false, firstPassEnv)
-	if err != nil && r.logger != nil {
+	prestate, err := c.ParseAndLoad([]byte(sanitized), baseDir, filename, r.env, false, firstPassEnv, overrode)
+	if err != nil {
 		if _, ok := err.(*state.StateLoadError); ok {
 			r.logger.Debugf("could not deduce `environment:` block, configuring only .Environment.Name. error: %v", err)
 		}
@@ -81,15 +83,13 @@ func (r *desiredStateLoader) renderTemplatesToYamlWithEnv(baseDir, filename stri
 
 func (r *desiredStateLoader) twoPassRenderTemplateToYaml(inherited, overrode *environment.Environment, baseDir, filename string, content []byte) (*bytes.Buffer, error) {
 	// try a first pass render. This will always succeed, but can produce a limited env
-	if r.logger != nil {
-		var phase string
-		if !runtime.V1Mode {
-			phase = "first-pass "
-		}
-		r.logger.Debugf("%srendering starting for \"%s\": inherited=%v, overrode=%v", phase, filename, inherited, overrode)
+	var phase string
+	if !runtime.V1Mode {
+		phase = "first-pass "
 	}
+	r.logger.Debugf("%srendering starting for \"%s\": inherited=%v, overrode=%v", phase, filename, inherited, overrode)
 
-	initEnv, err := inherited.Merge(overrode)
+	initEnv, err := inherited.Merge(nil)
 	if err != nil {
 		return nil, err
 	}
@@ -103,22 +103,24 @@ func (r *desiredStateLoader) twoPassRenderTemplateToYaml(inherited, overrode *en
 	if runtime.V1Mode {
 		var err error
 
-		finalEnv = initEnv
+		finalEnv, err = initEnv.Merge(overrode)
+		if err != nil {
+			return nil, err
+		}
 
 		vals, err = finalEnv.GetMergedValues()
 		if err != nil {
 			return nil, err
 		}
 	} else {
-		if r.logger != nil {
-			r.logger.Debugf("first-pass uses: %v", initEnv)
+		r.logger.Debugf("first-pass uses: %v", initEnv)
+		firstPassEnv, err := initEnv.Merge(nil)
+		if err != nil {
+			return nil, err
 		}
+		renderedEnv, prestate := r.renderPrestate(firstPassEnv, overrode, baseDir, filename, content)
 
-		renderedEnv, prestate := r.renderPrestate(initEnv, baseDir, filename, content)
-
-		if r.logger != nil {
-			r.logger.Debugf("first-pass produced: %v", renderedEnv)
-		}
+		r.logger.Debugf("first-pass produced: %v", renderedEnv)
 
 		mergedEnv, err := inherited.Merge(renderedEnv)
 		if err != nil {
@@ -130,9 +132,7 @@ func (r *desiredStateLoader) twoPassRenderTemplateToYaml(inherited, overrode *en
 			return nil, err
 		}
 
-		if r.logger != nil {
-			r.logger.Debugf("first-pass rendering result of \"%s\": %v", filename, *mergedEnv)
-		}
+		r.logger.Debugf("first-pass rendering result of \"%s\": %v", filename, *mergedEnv)
 
 		renderingPhase = "second-pass "
 
@@ -153,13 +153,9 @@ func (r *desiredStateLoader) twoPassRenderTemplateToYaml(inherited, overrode *en
 	renderer := tmpl.NewFileRenderer(r.fs, baseDir, tmplData)
 	yamlBuf, err := renderer.RenderTemplateContentToBuffer(content)
 	if err != nil {
-		if r.logger != nil {
-			r.logger.Debugf("%srendering failed, input of \"%s\":\n%s", renderingPhase, filename, prependLineNumbers(string(content)))
-		}
+		r.logger.Debugf("%srendering failed, input of \"%s\":\n%s", renderingPhase, filename, prependLineNumbers(string(content)))
 		return nil, err
 	}
-	if r.logger != nil {
-		r.logger.Debugf("%srendering result of \"%s\":\n%s", renderingPhase, filename, prependLineNumbers(yamlBuf.String()))
-	}
+	r.logger.Debugf("%srendering result of \"%s\":\n%s", renderingPhase, filename, prependLineNumbers(yamlBuf.String()))
 	return yamlBuf, nil
 }
