@@ -196,9 +196,14 @@ func (c *StateCreator) ParseAndLoad(content []byte, baseDir, file string, envNam
 }
 
 func (c *StateCreator) loadBases(envValues, overrodeEnv *environment.Environment, st *HelmState, baseDir string) (*HelmState, error) {
+	var newOverrodeEnv *environment.Environment
+	if overrodeEnv != nil {
+		overrodeEnvCopier := overrodeEnv.DeepCopy()
+		newOverrodeEnv = &overrodeEnvCopier
+	}
 	layers := []*HelmState{}
 	for _, b := range st.Bases {
-		base, err := c.LoadFile(envValues, overrodeEnv, baseDir, b, false)
+		base, err := c.LoadFile(envValues, newOverrodeEnv, baseDir, b, false)
 		if err != nil {
 			return nil, err
 		}
@@ -247,7 +252,7 @@ func (c *StateCreator) loadEnvValues(st *HelmState, name string, failOnMissingEn
 		return nil, &UndefinedEnvError{msg: fmt.Sprintf("environment \"%s\" is not defined", name)}
 	}
 
-	newEnv := &environment.Environment{Name: name, Values: envVals}
+	newEnv := &environment.Environment{Name: name, Values: envVals, KubeContext: envSpec.KubeContext}
 
 	if ctxEnv != nil {
 		intCtxEnv := *ctxEnv
