@@ -13,4 +13,6 @@ type EnvironmentSpec struct {
 	// Use "Warn", "Info", or "Debug" if you want helmfile to not fail when a values file is missing, while just leaving
 	// a message about the missing file at the log-level.
 	MissingFileHandler *string `yaml:"missingFileHandler,omitempty"`
+	// MissingFileHandlerConfig is composed of various settings for the MissingFileHandler
+	MissingFileHandlerConfig MissingFileHandlerConfig `yaml:"missingFileHandlerConfig,omitempty"`
 }
