@@ -235,6 +235,41 @@ func TestHelmState_flagsForUpgrade(t *testing.T) {
 				"--namespace", "test-namespace",
 			},
 		},
+		{
+			name: "enable-dns",
+			defaults: HelmSpec{
+				EnableDNS: false,
+			},
+			release: &ReleaseSpec{
+				Chart:     "test/chart",
+				Version:   "0.1",
+				EnableDNS: &enable,
+				Name:      "test-charts",
+				Namespace: "test-namespace",
+			},
+			want: []string{
+				"--version", "0.1",
+				"--enable-dns",
+				"--namespace", "test-namespace",
+			},
+		},
+		{
+			name: "enable-dns-from-default",
+			defaults: HelmSpec{
+				EnableDNS: true,
+			},
+			release: &ReleaseSpec{
+				Chart:     "test/chart",
+				Version:   "0.1",
+				EnableDNS: &disable,
+				Name:      "test-charts",
+				Namespace: "test-namespace",
+			},
+			want: []string{
+				"--version", "0.1",
+				"--namespace", "test-namespace",
+			},
+		},
 		{
 			name: "force",
 			defaults: HelmSpec{
@@ -1818,7 +1853,7 @@ func TestHelmState_DiffReleases(t *testing.T) {
 				valsRuntime:    valsRuntime,
 				RenderedValues: map[string]interface{}{},
 			}
-			_, errs := state.DiffReleases(tt.helm, []string{}, 1, false, false, []string{}, false, false, false, false, false)
+			_, errs := state.DiffReleases(tt.helm, []string{}, 1, false, false, false, []string{}, false, false, false, false, false)
 			if len(errs) > 0 {
 				t.Errorf("unexpected error: %v", errs)
 			}
@@ -2034,7 +2069,7 @@ func TestHelmState_DiffReleasesCleanup(t *testing.T) {
 				return nil
 			}
 			state = injectFs(state, testfs)
-			if _, errs := state.DiffReleases(tt.helm, []string{}, 1, false, false, []string{}, false, false, false, false, false); len(errs) > 0 {
+			if _, errs := state.DiffReleases(tt.helm, []string{}, 1, false, false, false, []string{}, false, false, false, false, false); len(errs) > 0 {
 				t.Errorf("unexpected errors: %v", errs)
 			}
 
@@ -2612,7 +2647,7 @@ func TestHelmState_Delete(t *testing.T) {
 				helm.Lists[exectest.ListKey{Filter: "^" + name + "$", Flags: tt.flags}] = name
 			}
 			affectedReleases := AffectedReleases{}
-			errs := state.DeleteReleases(&affectedReleases, helm, 1, tt.purge)
+			errs := state.DeleteReleases(&affectedReleases, helm, 1, tt.purge, "")
 			if errs != nil {
 				if !tt.wantErr || len(affectedReleases.Failed) != 1 || affectedReleases.Failed[0].Name != release.Name {
 					t.Errorf("DeleteReleases() for %s error = %v, wantErr %v", tt.name, errs, tt.wantErr)
@@ -2705,7 +2740,7 @@ func TestDiffpareSyncReleases(t *testing.T) {
 			Lists: map[exectest.ListKey]string{},
 			Helm3: true,
 		}
-		results, es := state.prepareDiffReleases(helm, []string{}, 1, false, false, []string{}, false, false, false, tt.diffOptions)
+		results, es := state.prepareDiffReleases(helm, []string{}, 1, false, false, false, []string{}, false, false, false, tt.diffOptions)
 
 		require.Len(t, es, 0)
 		require.Len(t, results, 1)
@@ -3190,3 +3225,33 @@ func TestGenerateChartPath(t *testing.T) {
 		})
 	}
 }
+
+func TestCommonDiffFlags(t *testing.T) {
+	tests := []struct {
+		name string
+		// stripTrailingCR is a flag to strip trailing carriage returns from the output
+		stripTrailingCR bool
+		expected        []string
+	}{
+		{
+			name:            "stripTrailingCR enabled",
+			stripTrailingCR: true,
+			expected: []string{
+				"--strip-trailing-cr",
+				"--reset-values",
+			},
+		},
+		{
+			name: "stripTrailingCR disenabled",
+			expected: []string{
+				"--reset-values",
+			},
+		},
+	}
+	for _, tt := range tests {
+		st := &HelmState{}
+		result := st.commonDiffFlags(false, tt.stripTrailingCR, false, []string{}, false, false, false, &DiffOpts{})
+
+		require.Equal(t, tt.expected, result)
+	}
+}
